@@ -287,34 +287,34 @@ fn parse_arguments(arg_vec: &Vec<&str>) -> Configuration {
                                 .required(true)
                                 .value_name("NEW_DICTIONARY_NAME")
                                 .takes_value(true)
-                                .about("Name for the dictionary to create."))
+                                .help("Name for the dictionary to create."))
                             .arg(Arg::new("initial_words_file")
                                 .long("initial_words_file")
                                 .short('i')
                                 .value_name("PATH_TO FILE_WITH_WORDS")
                                 .takes_value(true)
                                 .validator(file_exists)
-                                .about("Optionally you can load in the dictionary words located in a text file")))
+                                .help("Optionally you can load in the dictionary words located in a text file")))
                         .subcommand(App::new("delete")
                             .about("Remove an existing dictionary.")
                             .arg(Arg::new("dictionary_name").index(1)
                                 .required(true)
                                 .value_name("DICTIONARY_NAME_TO_DELETE")
                                 .takes_value(true)
-                                .about("Name for the dictionary to delete.")))
+                                .help("Name for the dictionary to delete.")))
                         .subcommand(App::new("update")
                             .about("Add words to an existing dictionary.")
                             .arg(Arg::new("dictionary_name").index(1)
                                 .required(true)
                                 .value_name("DICTIONARY_NAME_TO_UPDATE")
                                 .takes_value(true)
-                                .about("Name for the dictionary to update with additional words."))
+                                .help("Name for the dictionary to update with additional words."))
                             .arg(Arg::new("words_file").index(2)
                                 .required(true)
                                 .value_name("PATH_TO_FILE_WITH_WORDS")
                                 .takes_value(true)
                                 .validator(file_exists)
-                                .about("Pathname to a file with words to add to dictionary")))
+                                .help("Pathname to a file with words to add to dictionary")))
                         .subcommand(App::new("list")
                             .about("Show existing dictionaries.")))
         .subcommand(App::new("cipher")
@@ -324,30 +324,30 @@ fn parse_arguments(arg_vec: &Vec<&str>) -> Configuration {
                 .value_name("ALGORITHM_NAME")
                 .takes_value(true)
                 .possible_values(algorithm_options_str.as_slice())
-                .about("Algorithm to use to cipher."))
+                .help("Algorithm to use to cipher."))
             .arg(Arg::new("key").index(2)
                 .required(true)
                 .value_name("CIPHERING_KEY")
                 .takes_value(true)
-                .about("Key to use to cipher."))
+                .help("Key to use to cipher."))
             .arg(Arg::new("file_to_cipher").index(3)
                 .required(true)
                 .value_name("FILE_TO_CIPHER")
                 .takes_value(true)
                 .validator(file_exists)
-                .about("Path to file with text to cipher."))
+                .help("Path to file with text to cipher."))
             .arg(Arg::new("ciphered_file")
                 .long("ciphered_file")
                 .short('o')
                 .value_name("OUTPUT_CIPHERED_FILE")
                 .takes_value(true)
-                .about("Path to output file to place ciphered text. If not used then ciphered text will be dumped to console."))
+                .help("Path to output file to place ciphered text. If not used then ciphered text will be dumped to console."))
             .arg(Arg::new("charset")
                 .long("charset")
                 .short('c')
                 .value_name("CHARSET")
                 .takes_value(true)
-                .about(&format!("Default charset is: {}, but you can set here another", DEFAULT_CHARSET))))
+                .help(&format!("Default charset is: {}, but you can set here another", DEFAULT_CHARSET))))
         .subcommand(App::new("decipher")
             .about("Decipher a text using a key.")
             .arg(Arg::new("algorithm").index(1)
@@ -355,30 +355,30 @@ fn parse_arguments(arg_vec: &Vec<&str>) -> Configuration {
                 .value_name("ALGORITHM_NAME")
                 .takes_value(true)
                 .possible_values(algorithm_options_str.as_slice())
-                .about("Algorithm to use to decipher."))
+                .help("Algorithm to use to decipher."))
             .arg(Arg::new("key").index(2)
                 .required(true)
                 .value_name("CIPHERING_KEY")
                 .takes_value(true)
-                .about("Key to use to decipher."))
+                .help("Key to use to decipher."))
             .arg(Arg::new("file_to_decipher").index(3)
                 .required(true)
                 .value_name("FILE_TO_DECIPHER")
                 .takes_value(true)
                 .validator(file_exists)
-                .about("Path to file with text to decipher."))
+                .help("Path to file with text to decipher."))
             .arg(Arg::new("deciphered_file")
                 .long("deciphered_file")
                 .short('o')
                 .value_name("OUTPUT_DECIPHERED_FILE")
                 .takes_value(true)
-                .about("Path to output file to place deciphered text. If not used then deciphered text will be dumped to console."))
+                .help("Path to output file to place deciphered text. If not used then deciphered text will be dumped to console."))
             .arg(Arg::new("charset")
                 .long("charset")
                 .short('c')
                 .value_name("CHARSET")
                 .takes_value(true)
-                .about(&format!("Default charset is: {}, but you can set here another", DEFAULT_CHARSET))))
+                .help(&format!("Default charset is: {}, but you can set here another", DEFAULT_CHARSET))))
         .subcommand(App::new("attack")
             .about("Attack a ciphered text to get its plain text")
             .arg(Arg::new("algorithm").index(1)
@@ -386,29 +386,29 @@ fn parse_arguments(arg_vec: &Vec<&str>) -> Configuration {
                 .value_name("ALGORITHM_NAME")
                 .takes_value(true)
                 .possible_values(algorithm_options_str.as_slice())
-                .about("Algorithm to attack."))
+                .help("Algorithm to attack."))
             .arg(Arg::new("file_to_attack").index(2)
                 .required(true)
                 .value_name("FILE_TO_ATTACK")
                 .takes_value(true)
                 .validator(file_exists)
-                .about("Path to file with text to attack."))
+                .help("Path to file with text to attack."))
             .arg(Arg::new("deciphered_file")
                 .short('o')
                 .long("deciphered_file")
                 .value_name("OUTPUT_DECIPHERED_FILE")
                 .takes_value(true)
-                .about("Path to output file to place deciphered text. If not used then deciphered text will be dumped to console."))
+                .help("Path to output file to place deciphered text. If not used then deciphered text will be dumped to console."))
             .arg(Arg::new("output_recovered_key")
                 .short('k')
                 .long("output_recovered_key")
-                .about("Include guessed key in output. If not used only recovered text is output."))
+                .help("Include guessed key in output. If not used only recovered text is output."))
             .arg(Arg::new("charset")
                 .short('c')
                 .long("charset")
                 .value_name("CHARSET")
                 .takes_value(true)
-                .about(&format!("Default charset is: {}, but you can set here another", DEFAULT_CHARSET))))
+                .help(&format!("Default charset is: {}, but you can set here another", DEFAULT_CHARSET))))
         .get_matches_from(arg_vec);
     let configuration = Configuration::from(matches);
     configuration
